## Submitting Pull Requests

Before changes can be accepted a Contributor Licensing Agreement for  [Individual](https://docs.google.com/forms/d/1d2R9aVafHTasTYirq-qZx_lx20Obss0ufUS-OtLpu20/viewform) |  [Corporate](https://docs.google.com/forms/d/1hj5s1bkbmO1OP-UKnSNS6dsDkL1jFDL2XZ5d4IIFdb4/viewform) must be completed.

 * If you are an individual writing original source code and you're sure you own the intellectual property, then you'll need to sign an [Individual CLA](https://docs.google.com/forms/d/1d2R9aVafHTasTYirq-qZx_lx20Obss0ufUS-OtLpu20/viewform).
 * If you work for a company that wants to allow you to contribute your work, then you'll need to sign a [Corporate CLA](https://docs.google.com/forms/d/1hj5s1bkbmO1OP-UKnSNS6dsDkL1jFDL2XZ5d4IIFdb4/viewform).

*!Caution : due to legal obligations, this CLA does not apply to korean users, see below for the details.*

### For Koreans

If you are Korean, please e-mail at oss@kakaocorp.com for agreeing to the our privacy policy. Then we will send you a CLA copy.

